-- Scriptlet to generate a list of all SPs for the current DB.
-- Includes all parameters for the SPs, datatype and nullability.
-- Useful if building an offline data dictionary or documentation.
--
-- Author: Derek Colley, derek@derekcolley.co.uk, 08/08/12
-- 
-- Modification History:
-- =================================================
-- 2012/08/08 Initial Version  Derek Colley
--------------------------------------------------------------

-- Create a temp table to house the output of sp_sproc_columns 
DECLARE @t1 TABLE 
( 
    PROCEDURE_QUALIFIER nvarchar ( max ) , PROCEDURE_OWNER nvarchar ( max ) , 
    PROCEDURE_NAME nvarchar ( max ) , COLUMN_NAME nvarchar ( max ) , 
    COLUMN_TYPE smallint , DATA_TYPE smallint , 
    [TYPE_NAME] nvarchar ( max ) , [PRECISION] int , 
    LENGTH int , SCALE int , 
    RADIX int , NULLABLE bit , 
    REMARKS nvarchar ( max ) , COLUMN_DEF nvarchar ( max ) , 
    SQL_DATA_TYPE int , SQL_DATETIME_SUB int , 
    CHAR_OCTET_LENGTH int , ORDINAL_POSITION int , 
    IS_NULLABLE nvarchar ( 100 ) , SS_DATA_TYPE bigint ) 

-- Populate the table 
INSERT INTO @t1 

EXEC sp_sproc_columns 

-- Define a target table for the columns we' re interested IN 
DECLARE @procedureListTable TABLE 
( 
    sch_name nvarchar ( max ) , proc_name nvarchar ( max ) , 
    col_name nvarchar ( max ) , col_type nvarchar ( max ) , 
    nullable bit ) 

-- Populate this table (filtering from @t1, pick your own columns) 
INSERT INTO @procedureListTable 
SELECT 
PROCEDURE_OWNER , 
PROCEDURE_NAME , 
COLUMN_NAME , 
TYPE_NAME , 
NULLABLE 
FROM 
@t1 
ORDER BY PROCEDURE_OWNER ASC , 
PROCEDURE_NAME ASC , 
COLUMN_NAME ASC 

-- Dump output.  Send this to a table / SSIS / Excel as you see fit.

SELECT * FROM @procedureListTable